function y = fdis_prb( x, m, n)
% PURPOSE: computes f-distribution probabilities
%---------------------------------------------------
% USAGE: y = fdis_prb(x,m,n)
% INPUTS:  x = calculated f-statistic
%          m = numerator dof
%          n = denominator dof
%---------------------------------------------------
% RETURNS:
%        y = a marginal probability level
% --------------------------------------------------
% SEE ALSO: tdis_prb(), chis_prb()
%---------------------------------------------------

% written by:
% James P. LeSage, Dept of Economics
% University of Toledo
% 2801 W. Bancroft St,
% Toledo, OH 43606
% jpl@jpl.econ.utoledo.edu

if nargin ~= 3
error('Wrong # of arguments to fdis_prb');
end;

[np junk] = size(x);
y = zeros(np,1);

for i=1:np;
 if (x(i) < 0 | m <= 0 | n <= 0)
  error('negative or zero dof in fdis_prb');
 else
  y(i,1) = betai(.5*n,.5*m,n/(n+m*x(i,1)));
    end;
end;    