function [P,R,U,T]=deterministic_dynamics(cs,zs,x_bar,m_bar,v_bar,ZS,parameters,rho_y,rho_I);

beta=parameters(1);				%% time discount factor
sigma=parameters(2);			%% coefficient of relative risk aversion
N=parameters(3);				%% length of a shopping trip (no. of periods). 
								%% Also, inv(N) is measure of each type of shopper s=0,..,N-1 
gamma=parameters(4);			%% paycheck parameter
y_bar=parameters(5);			%% mean of income shock
mu_bar=parameters(6);			%% mean of money growth factor shock


%%%%% Set up matrices of unknowns

J=N-1;

U=zeros(J,J);
T=zeros(J,J);

RcsU=zeros(J,N);					%% each *row* has as many elements as cs (= N)
RpiU=zeros(J,1);					%% has as many elements as there are *columns* of U

%%%%% Begin loop over columns of U

for j=1:J,
   
   j;
   n=j-1;							%% number of orthogonality conditions
   
   %% The A matrix has 5 blocks. There are L equations and L+1 unknowns where:
   
	L=1+(N-1)+1+(N-2)+n;			%% 1 		resource constraint
   									%% N-1   cash flow equations for s=1,...,N-1 
                              %% 1     Euler equation for s=0
                              %% N-2   cash Euler equations for s=0,...,N-3
                              %%	n		orthogonality conditions
                                                            
                              
	%% Block 1 (resource constraint)
                                                            
   a11=zeros(N,1);
   a12=zeros(1,1);
   a13=zeros(N-1,1);
   a14=zeros(n,1);
   
   a11=cs;
   
   A1=[a11;a12;a13;a14];
      
   %% Block 2 (cash flow equations for s=1,...,N-1)
  
   a21=zeros(N,N-1);
   a22=zeros(1,N-1);
   a23=zeros(N-1,N-1);
   a24=zeros(n,N-1);
   
   for i=1:N-1,
      a21(i+1,i)=-cs(i+1);
      a22(i)=-((zs(i)+(gamma*y_bar))/mu_bar);
      a23(i,i)=(zs(i)/mu_bar);
   end
   
   if n>0,
      for i=1:N-1,
      	for k=1:n,
         	if i==N-1
            	a24(k,i)=0;
 				else
               a24(k,i)=-zs(i+1)*U(i+1,k);
            end
         end
      end
   else
      a24=zeros(n,N-1);
   end
   
   A2=[a21;a22;a23;a24];
      
   %% Block 3 (Euler equation for s=0) **trickiest of all**
   
   a31=zeros(N,1);
   a32=zeros(1,1);
   a33=zeros(N-1,1);
   a34=zeros(n,1);
   
   a31(1,1)=sigma;
   
   if n>0
      for k=1:n,
      	a34(k)=-sigma*RcsU(k,2)-RpiU(k);
   	end
   end
      
   A3=[a31;a32;a33;a34];
   
   %% Block 4 (cash Euler equations for s=0,...,N-3) 
   
   a41=zeros(N,N-2);
   a42=zeros(1,N-2);
   a43=zeros(N-1,N-2);
   a44=zeros(n,N-2);
  
   for i=1:N-2,
      a41(i,i)=1;
      a41(i+1,i)=-1;
   end
   
   if n>0
      for i=1:N-2,
         for k=1:n,
            a44(k,i)=-RcsU(k,i+1)+RcsU(k,i+2);            
         end
      end
   end
      
   A4=[a41;a42;a43;a44];   
   
   %% Block 5 (orthogonality conditions)
   
   a51=zeros(N,n);
   a52=zeros(1,n);
   a53=zeros(N-1,n);
  	a54=zeros(n,n);
   
   if n==0,
      A5=[];
   else
      
		for i=1:N-1,
         for k=1:n,
            a53(i,k)=U(i,k);
         end
      end
      
      A5=[a51;a52;a53;a54];
      
	end
   
   A=[A1,A2,A3,A4,A5];
   
   %%%%% Obtain null space (hopefully one-dimensional)
   
   solution=null(A');
   test1=max(abs(A'*solution));
   
   %%%%% Scale
   
   u=solution(N+2:N+N);
   
   if n==0
   	t=[];
   else
      t=solution(N+J+2:L+1);
   end
   
   factor=inv(sqrt(u'*u));
   
   u=factor*u;
   t=factor*t;
   
   solution2=factor*solution;
   
   %%%%% Save elements of U and T matrices for use in next loops
   
   U(:,j)=u;
   
   
   if n==0
      T(1,1)=0;
   else
      nt=length(t);
      for l=1:nt,
         T(l,j)=t(l);
      end   
      
   end
   
   
   %%%%% Recover other needed elements
   
   RcsU(j,:)=solution2(1:N)';
   RpiU(j)=solution2(N+1);
   
      

end

%%%%% Compute PP matrix

P=U*T*U';

%%%%% Compute RR matrix

X=[RcsU,RpiU]';

R=X*inv(U);

