%%%%% Revised figures

clear all

%%%%% Load in data downloaded from FRED

[num,txt,raw] = xlsread('data.xls'); %FEDFUNDS	GS3	M1SL	M2SL	PCE	PCEND	PCEPI	PCES

dates = 1959:1/12:2006+11/12'; T = length(dates);


ff = num(:,1)/100;
t3 = num(:,2)/100;

m1 = log(num(:,3));
m2 = log(num(:,4));

pc = log(num(:,6)+num(:,8));
p  = log(num(:,7));
c  = pc-p;

v1 = p + c - m1;
v2 = p + c - m2;

m1c = m1 - c;
m2c = m2 - c;


%%%%% HP filter with smoothing parameter phi

phi  = 1600*3^4; %%1660*3^2; %% the two smoothing parameters used in Appendix A

[m1t,m1d] = hptrend(m1,phi);
[m2t,m2d] = hptrend(m2,phi);
[pt ,pd ] = hptrend(p ,phi);
[ct ,cd ] = hptrend(c ,phi);
[fft,ffd] = hptrend(ff,phi);
[t3t,t3d] = hptrend(t3,phi);
[v1t,v1d] = hptrend(v1,phi);
[v2t,v2d] = hptrend(v2,phi);
[m1ct,m1cd] = hptrend(m1c,phi);
[m2ct,m2cd] = hptrend(m2c,phi);


%%%%% Figure

figure(1)
plot(dates,m2cd,dates,v2d,dates,zeros(T,1),'k--')
axis([1959 2006 -0.05 0.06])
xlabel('year')
ylabel('deviation from HP trend')
title('Figure I: Short run negative correlation of M/c and v')
text(1995,0.02,'log(v)')
text(2000,-0.03,'log(M/c)')

%%%%% Alternative measures of short run fluctuations as used in Appendix A

%%%%% HP filter

cm2cvhp = corrcoef([m2cd,v2d])
sm2cvhp = std(v2d)/std(m2cd)

%%%%% Monthly differences

m2cd = diff(m2c);
v2d  = diff(v2);

cm2cv1 = corrcoef(m2cd,v2d)
sm2cv1 = std(v2d) /std(m2cd) 

%%%%% Annual differences

for t=13:T,
    
    m2cd12(t-12) = m2c(t)-m2c(t-12);
    v2d12(t-12) = v2(t) - v2(t-12);
    
end

cm2cv12 = corrcoef(m2cd12,v2d12)
sm2cv12 = std(v2d12)/std(m2cd12)



