%%%%% Computations for Baumol-Tobin project

clear all
tic;

%%%%% 1a.	Declare structural parameters

period=12;						%% frequency of the model: 12=monthly, 4=quarterly etc
beta=(0.99)^(1/period);	    %% time discount factor	
sigma=1;						%% coefficient of relative risk aversion
N=38;							%% length of a shopping trip (no. of periods). 
								%% Also, inv(N) is measure of each type of shopper s=0,..,N-1 
gamma=0.6;						%% paycheck parameter

y_bar=1;							%% mean of income shock
rho_y=0.95;						%% persistence of income shock;
sigma_y=0.013;					%% standard deviation of income innovation

mu_bar=(1.01)^(1/period);	    %% mean of money growth factor shock
rho_I=0.87;						%% persistence of interest shock
sigma_I=0.25;					%% standard deviation of interest innovation             

								%% standard deviation of "sunspot" (expectational error) shock
%sigma_S=0.0310;				%% N=38, gamma=0.0                           
%sigma_S=4.5417*sigma_I;	        %% N=38, gamma=0.6
%sigma_S=-3.8629*sigma_I;        %% N=38, gamma=0.6, sigma=3

%sigma_S=2.9671*sigma_I;         %% N=38, gamma =0.6, rho_I=0.87

%sigma_S=18.4321;				%% N=38, gamma=0.85
%sigma_S=0.0723;				%%	N=15, gamma=0.0
%sigma_S=1.5070;				%%	N=15, gamma=0.6
%sigma_S=4.3376;				%%	N=15, gamma=0.85

%sigma_S=0.1179;				%% N=9, gamma=0.0
%sigma_S=0.8333;				%% N=9, gamma=0.6
%sigma_S=1.1256;				%% N=9, gamma=0.7
%sigma_S=1.8622;				%% N=9, gamma=0.85


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%% 3.		Pass these parameters to the steady state function

parameters=[beta,sigma,N,gamma,y_bar,mu_bar];

[cs,ms,x]=steady_state(parameters);
					%% cs is an N-vector of consumptions for each s=0,...,N-1
               %% ms is an N-vector of real balances for each s=1,...,N
               %% x is level of transfers. Note m(0)=m(N)+x=x               
               
%%%%%	4.		Check that we have an interior solution for the money holdings

indicator=zeros(N,1);	%% see if there are corners

for s=1:N,
   if ms(s)>=0;
      indicator(s)=1;
   else
      indicator(s)=0;
   end
end

lever=min(indicator);	%% if there are any corners, resolve using the kinky program
if lever>0
else
   [cs,ms,x,J]=resolve_kinks(parameters,indicator);
end

Ec=mean(cs);
Em=mean(ms);               
test=y_bar-Ec;
x_bar=x;               
m_bar=Em+Ec;
v_bar=y_bar/m_bar;
zs=ms(1:N-1);		%% swapped notation zs were ms!!
ZS=sum(zs);              

%%%%% 5.		Input steady state values to a function that sets up the matrices for
%				use with Harald Uhlig's toolkit

%				Make sure that matrices computed at this step use the "right" policy process,
%				i.e., is money exogenous? or the nominal interest rate? or what?

[AA,BB,CC,DD,FF,JJ,KK,NN,MM]=matrices_interest(cs,zs,x_bar,m_bar,v_bar,ZS,parameters,rho_y,rho_I);


%%%%% 5.		Pass these matrices and other parameters to a program that solves for the 
%				deterministic dynamics

[PP,RR,U,T]=deterministic_dynamics(cs,zs,x_bar,m_bar,v_bar,ZS,parameters,rho_y,rho_I);

Rcs=RR(1:N,:);
Rpi=RR(N+1,:);

PP=[PP,zeros(N-1,1);Rpi,0];
RR=[Rcs,zeros(N,1)];

RRdd=RR;	%% This enables us to check that the RR matrix computed "by hand" and the RR matrix 
			%% from Harald's program are the same. 
         
PPdd=PP;         
         
%%%%% 6.		Compute QQ,SS matrices. 

GG=zeros(N,N);
HH=zeros(N,N);
LL=zeros(N,1);

[PP,QQI,RR,SSI]=harald(AA,BB,CC,DD,FF,GG,HH,JJ,KK,LL,MM,NN,PP);

XX=[AA,CC;FF*PP+GG+JJ*RR,KK];	
xx=null(XX);
xx=xx/xx(N);

QQpi=xx(1:N);
SSpi=xx(N+1:2*N);

QQ=[QQI,QQpi];
SS=[SSI,SSpi];


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%% 7.		Impulse responses

NNN=[NN,0;0,0];
DDD=[DD,DD];

%shock = [1;0.8958]; %% N=38, gamma=0.6, sigma=3
shock=[1;-2.4401]; %% N=38, gamma=0.6. sigma=1

%shock=[1;-0.0310];	%% N=38, gamma=0.0
%shock=[1;-4.5417];	%% N=38, gamma=0.6
%shock=[1;-2.9671];  %% N=38, gamma=0.6. rho_I=0.87
%shock=[1;-18.4321];%% N=38, gamma=0.85

%shock=[1;-1.5070];	%% N=15, gamma=0.6
%shock=[1;-0.0723];	%% N=15, gamma=0.0
%shock=[1;-4.3376];	%% N=15, gamma=0.85

%shock=[1;-0.1179];	%% N=9, gamma=0.0
%shock=[1;-0.8333];	%% N=9, gamma=0.6
%shock=[1;-1.1256];	%% N=9, gamma=0.7
%shock=[1;-1.8622];	%% N=9, gamma=0.85

H=50;

X=zeros(N,H+2);
Y=zeros(N,H+2);
Z=zeros(2,H+2);
V=zeros(1,H+2);
TEST=zeros(N,H+1);
DV=zeros(1,H+1);

for h=3:H+2,
   Z(:,2)=shock;
   Z(:,h)=NNN*Z(:,h-1);
end

for h=2:H+2,   
   X(:,h)=PP*X(:,h-1)+QQ*Z(:,h);
   Y(:,h)=RR*X(:,h-1)+SS*Z(:,h);
      
   V(h)=-(1/N)*sum((zs/m_bar).*X(1:N-1,h));
   DV(h)=V(h)-V(h-1);
   
end

%%				Test that we have a correct solution. Given a {X,Y,Z} path found by iterating on (P,Q,R,S),
%%				check that Ax(t)+Bx(t-1)+Cy(t)+Dz(t)=0 for all t

for h=2:H+2,
   TEST(:,h)=AA*X(:,h)+BB*X(:,h-1)+CC*Y(:,h)+DDD*Z(:,h);
end

%%				Test statistic should be (approximately) zero

test_statistic=max(max(abs(TEST')));


nominal_interest=Z(1,:)';
sunspot=Z(2,:)';
inflation=X(N,:)';
money_growth=inflation-DV';

log_M=cumsum(money_growth);
log_P=cumsum(inflation);
log_V=log_P-log_M;

time=[-1;0;cumsum(ones(H,1))];

figure(5)
plot(time,nominal_interest,time,log_P,time,log_M,time,log_V,time,zeros(H+2,1),'k--')
title('Figure V: Sluggish price response to persistent interest rate shock')
%legend('log(1+i)','log(P)','log(M/c)','log(v)',2)
xlabel('months after shock')
ylabel('percent deviation from steady state')
axis([-1 50 -2 4])
text(5,1.85,'log(v)')
text(5,0.60,'log(1+i)')
text(5,-0.30,'log(P)')
text(12.5,-1.25,'log(M/c)')


figure(4)
plot(time,nominal_interest,time,inflation,time,money_growth,time,DV,time,zeros(H+2,1),'k--')
title('Figure IV: Large liquidity effects')
%legend('log(1+i)','\Delta log(P)','\Delta log(M)','\Delta log(v)',1)
xlabel('months after shock')
ylabel('percent deviation from steady state')
axis([-1 50 -0.65 1.2])
text(1.5,0.9,'log(1+i)')
text(0.05,-0.1,'\Delta log(P)')
text(1.1,-0.55,'\Delta log(M)')
text(15,-0.15,'\Delta log(v)')




