%%%%% This function sets up the matrices for input into Harald Uhlig's toolkit
%%%%% This version does the case where the nominal interest rate is an exogenous process
%%%%% Modified program for use in the special case of N=1

function [AA,BB,CC,DD,FF,JJ,KK,NN,MM]=matrices_interest2(cs,zs,x_bar,m_bar,v_bar,ZS,parameters,rho_y,rho_I);

beta=parameters(1);				%% time discount factor
sigma=parameters(2);				%% coefficient of relative risk aversion
N=parameters(3);					%% length of a shopping trip (no. of periods). 
										%% Also, inv(N) is measure of each type of shopper s=0,..,N-1 
gamma=parameters(4);				%% paycheck parameter
y_bar=parameters(5);				%% mean of income shock
mu_bar=parameters(6);			%% mean of money growth factor shock

%		Notation: double letters indicate bold. e.g., AA=bold(A)

%%%%% Blocks for exogenous stochastic processes

NN=rho_I;

%%%%% Blocks for contemporaneous endogenous variables

%%		AA matrix

a11=zeros(1,1);
a12=zeros(1,N-2);
a13=zeros(1,1);
a21=zeros(N-2,1);
a22=zeros(N-2,N-2);

for i=1:N-2,
   a22(i,i)=-zs(i+1);
end

a23=zeros(N-2,1);

for i=1:N-2,
   a23(i)=-((zs(i)+gamma*y_bar)/mu_bar);
end

a31=zeros(1,1);
a32=zeros(1,N-2);
a33=zeros(1,1);
a33=-((zs(N-1)+gamma*y_bar)/mu_bar);

AA=[a11,a12,a13;a21,a22,a23;a31,a32,a33];

%%		BB matrix

b11=zeros(1,N-1);
b12=zeros(1,1);
b21=zeros(N-1,N-1);

for i=1:N-1,
   b21(i,i)=(zs(i)/mu_bar);
end

b22=zeros(N-1,1);

BB=[b11,b12;b21,b22];

%%		CC matrix

c11=zeros(1,N);

for i=1:N,
   c11(i)=cs(i);
end

c21=zeros(N-1,N);

for i=1:N-1
   c21(i,i+1)=-cs(i+1);
end

CC=[c11;c21];

%%		DD matrix

DD=zeros(N,1);

%%%%% Blocks for Euler-like equations

%% 	FF matrix

FF=zeros(N,N);
FF(N,N)=-1;

%%		JJ matrix

j11=zeros(1,N);
j11(1)=1;
j11(2)=-1;
j21=zeros(N-2,N);

for i=1:N-2,
   j21(i,i+1)=-1;
   j21(i,i+2)=1;
end

j31=zeros(1,N);
j31(N)=-sigma;

JJ=[j11;j21;j31];

%%		KK matrix

k11=zeros(1,N-1);
k12=zeros(1,1);
k21=zeros(N-2,N-1);

for i=1:N-2,
   k21(i,i)=1;
   k21(i,i+1)=-1;
end

k22=zeros(N-2,1);
k31=zeros(1,N-1);
k31(N-1)=sigma;
k32=zeros(1,1);

KK=[k11,k12;k21,k22;k31,k32];

%%		MM matrix

m11=zeros(1,1);

m11(1)=-1;

m21=zeros(N-1,1);

MM=[m11;m21];

