%%%%% This function sets up the matrices for input into Harald Uhlig's toolkit
%%%%%

function [NN,JJ,KK,AA,BB,CC,DD]=matrices_money(parameters,cs,zs,m_bar,v_bar,rho_y,rho_mu)

%beta=parameters(1);				%% time discount factor
sigma=parameters(2);			%% coefficient of relative risk aversion
N=parameters(3);				%% length of a shopping trip (no. of periods). 
								%% Also, inv(N) is measure of each type of shopper s=0,..,N-1 
gamma=parameters(4);			%% paycheck parameter
y_bar=parameters(5);			%% mean of income shock
mu_bar=parameters(6);			%% mean of money growth factor shock

%		Notation: double letters indicate bold. e.g., AA=bold(A)

%		Exogenous shock processes: zz'=NNzz+ee

NN=[rho_y,0,0;1,0,0;0,0,rho_mu];

%		Euler equations: 00=E{JJyy'+KKyy}

iota=ones(N-1,1);
ohs=zeros(N-1,1);

JJ=[-iota,ohs,-sigma*eye(N-1)];
KK=[ohs,sigma*eye(N-1),ohs];

%		Other equilibrium relationships: 00=AAxx+BBL{xx}+CCyy+DDzz

AA=zeros(N+1,N-1);

AA(1,1)=-(1/N)*(zs(1)/m_bar);

for i=2:N-1,
   a=zeros(N+1,1);
   a(1)=-(1/N)*(zs(i)/m_bar);
   a(i+1)=-zs(i);
   AA(:,i)=a;
end

BB=zeros(N+1,N-1);

for i=1:N-1,
   b=zeros(N+1,1);
   b(1)=(1/N)*(zs(i)/m_bar);
   b(i+2)=zs(i)/mu_bar;
   BB(:,i)=b;
end

CC=zeros(N+1,N+1);

CC(1,1)=-1;

for j=3:N+1,
   CC(j,1)=-(zs(j-2)+(gamma*y_bar))/mu_bar;
end
for i=1:N,
   CC(2,i+1)=-cs(i);
end
for i=2:N,
   CC(i+1,i+1)=-cs(i);
end

DD=zeros(N+1,3);

DD(1,:)=[-v_bar,v_bar,1];
DD(2,:)=[0,N*y_bar,0];

for j=3:N+1,
   DD(j,2)=gamma*(y_bar/mu_bar);
end



