%%%%% This function sets up the matrices for input into Harald Uhlig's toolkit
%%%%%

function [NN,JJ,KK,AA,BB,CC,DD]=matrices_money_var(cs,zs,x_bar,m_bar,v_bar,ZS,parameters,L);

beta=parameters(1);				%% time discount factor
sigma=parameters(2);				%% coefficient of relative risk aversion
N=parameters(3);					%% length of a shopping trip (no. of periods). 
										%% Also, inv(N) is measure of each type of shopper s=0,..,N-1 
gamma=parameters(4);				%% paycheck parameter
y_bar=parameters(5);				%% mean of income shock
mu_bar=parameters(6);			%% mean of money growth factor shock

%		Notation: double letters indicate bold. e.g., AA=bold(A)

%		Exogenous shock processes: zz'=NNzz+ee from estimated VAR

[num] = xlsread('data.xls'); %FEDFUNDS	GS3	M1SL	M2SL	PCE	PCEND	PCEPI	PCES

%dates = 1959:1/12:2006+11/12';

%ff = num(:,1)/100;
%t3 = num(:,2)/100;

%m1 = log(num(:,3));
m2 = log(num(:,4));

pc = log(num(:,5));
p  = log(num(:,7));
c  = pc-p;

%v1 = p + c - m1;
%v2 = p + c - m2;

%m1c = m1 - c;
%m2c = m2 - c;

%%%%% Construct data vectors

Dm = diff(m2);
Dc = diff(c);

vnames=strvcat('M2 growth','real C growth');

%c=log(realpce5901);
%c=c(2:length(c));

%%%%% Estimate VAR. This returns a structure. 

results=VAR([Dm,Dc],L);

beta_Dm = results(1).beta;      %% returns a 2*L+1 vector of coefficients for the Dm (1st) equation
beta_Dc = results(2).beta;      %% returns a 2*L+1 vector of coefficients for the Dc (2nd) equation

% these coefficients are ordered as follows:

                                %% 1) lags of M2 growth (1st dependent variable) 1:L
                                %% 2) lags of real pce growth (2nd dependent variable) 1:L
                                %% 3) constant

prt_var(results,vnames);        %% use if want to see results stucture prettied up

% map change coefficients into levels coefficients for real consumption

beta_Dm_Dm=beta_Dm(1:L);
beta_Dm_Dc=beta_Dm(L+1:2*L);
%beta_Dm_const=beta_Dm(2*L+1);

beta_Dc_Dm=beta_Dc(1:L);
beta_Dc_Dc=beta_Dc(L+1:2*L);
%beta_Dc_const=beta_Dc(2*L+1);

for i=1:L+1,
    if i==1,
        beta_Dm_c(i)=beta_Dm_Dc(i);
        beta_c_c(i)=1+beta_Dc_Dc(i);
elseif i==L+1,
        beta_Dm_c(i)=-beta_Dm_Dc(i-1);
        beta_c_c(i)=-beta_Dc_Dc(i-1);
else
        beta_Dm_c(i)=beta_Dm_Dc(i)-beta_Dm_Dc(i-1);
        beta_c_c(i)=beta_Dc_Dc(i)-beta_Dc_Dc(i-1);
    end
end


%beta_Dm=[beta_Dm_Dm;beta_Dm_c';beta_Dm_const];
%beta_c=[beta_Dc_Dm;beta_c_c';beta_Dc_const];
        
% construct "NN" matrix for law of motion of exogenous stochastic processes
% NN is 2*L+1 by 2*L+1

NN=zeros(2*L+1,2*L+1);

NN(1,:)=[beta_c_c';beta_Dc_Dm]';

for i=2:L+1,
    NN(i,i-1)=1;
end

NN(L+2,:)=[beta_Dm_c';beta_Dm_Dm]';

for i=L+3:2*L+1,
    NN(i,i-1)=1;
end

[nz,nz]=size(NN);

%		Euler equations: 00=E{JJyy'+KKyy}

iota=ones(N-1,1);
ohs=zeros(N-1,1);

JJ=[-iota,ohs,ohs,-sigma*eye(N-1)];
KK=[ohs,ohs,sigma*eye(N-1),ohs];

%		Other equilibrium relationships: 00=AAxx+BBL{xx}+CCyy+DDzz

AA=zeros(N+2,N-1);

for i=1:N-1,
   a=zeros(N+2,1);
   a(1)=-(1/N)*(zs(i)/m_bar);
   a(2)=(1-inv(mu_bar))*zs(i);
   a(i+2)=-zs(i);
   AA(:,i)=a;
end

BB=zeros(N+2,N-1);

for i=1:N-1,
   b=zeros(N+2,1);
   b(1)=(1/N)*(zs(i)/m_bar);
   b(i+3)=zs(i)/mu_bar;
   BB(:,i)=b;
end

CC=zeros(N+2,N+2);

CC(1,1)=-1;
CC(2,1)=N*gamma*(y_bar/mu_bar);
CC(3,1)=-gamma*(y_bar/mu_bar);
for j=4:N+2,
   CC(j,1)=-(zs(j-3)+(gamma*y_bar))/mu_bar;
end
CC(2,2)=-x_bar;
CC(3,2)=x_bar;
for i=1:N,
   CC(i+2,i+2)=-cs(i);
end

DD=zeros(N+2,nz);

DD(:,1)=[-v_bar;N*y_bar;gamma*(y_bar/mu_bar)*ones(N,1)];

DD(:,2)=[v_bar;-N*gamma*(y_bar/mu_bar);zeros(N,1)];

DD(:,L+2)=[1;ZS/mu_bar;zeros(N,1)];





