%%%%% Computations for Baumol-Tobin project

clc
clear all
warning('off','MATLAB:dispatcher:InexactCaseMatch')
tic;

%%%%% 1.	Declare structural parameters

period=12;						%% frequency of the model: 12=monthly, 4=quarterly etc
beta=(1/1.01)^(1/period);	    %% time discount factor	
sigma=1;						%% coefficient of relative risk aversion
N=15;							%% length of a shopping trip (no. of periods). 
								%% Also, inv(N) is measure of each type of shopper s=0,..,N-1 
gamma=0.00;						%% paycheck parameter

y_bar=1;						%% mean of income shock
rho_y=0.95;						%% persistence of income shock;
sigma_y=0.013;					%% standard deviation of income innovation

mu_bar=(1.01)^(1/period);	    %% mean of money growth factor shock
rho_mu=0.00;					%% persistence of money growth shock
sigma_mu=1;						%% standard deviation of money growth innovation               

rho_y_mu=0.000;				    %% contemporaneous correlation of shocks

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%% 2.		Pass structural parameters to the steady state function

parameters=[beta,sigma,N,gamma,y_bar,mu_bar];

[cs,zs,x]=steady_state(parameters);
			   %% cs is an N-vector of consumptions for each s=0,...,N-1
               %% ms is an N-vector of real balances for each s=1,...,N
               %% x is level of transfers. Note m(0)=m(N)+x=x               
               
%%%%% 3.        Check that we have an interior solution for the money holdings

indicator=zeros(N,1);	%% see if there are corners

for s=1:N,
   if zs(s)>=0;
      indicator(s)=1;
   else
      indicator(s)=0;
   end
end



lever=min(indicator);	%% if there are any corners, resolve using the kinks program
if lever==0
   [cs,zs,x,J]=resolve_kinks(parameters,indicator);
end

Ec=mean(cs);
Ez=mean(zs);               
x_bar=x;               
m_bar=Ez+Ec;
v_bar=y_bar/m_bar;

ZS=sum(zs);              

%%%%% 4.		Input steady state values to a function that sets up the matrices for
%				use with Harald Uhlig's toolkit

[NN,JJ,KK,AA,BB,CC,DD]=matrices_money(parameters,cs,zs,m_bar,v_bar,rho_y,rho_mu);

FF=zeros(N-1,N-1);
GG=zeros(N-1,N-1);
HH=zeros(N-1,N-1);
LL=zeros(N-1,3);
MM=zeros(N-1,3);

     
%%%%% 5.		Call Harald Uhlig's toolkit. The equilibrium laws of motion are: 
%				xx=PPL{xx}+QQzz
%				yy=RRL{xx}+SSzz
%				zz'=NNzz+ee'

[l_equ,m_states] = size(AA);
[l_equ,n_endog ] = size(CC);
[l_equ,k_exog  ] = size(DD);

message = '                                                                       ';
warnings = [];
options;
solve;

%%%%% Impulse response analysis: 

H=60;		
hs=[-1;0;cumsum(ones(H,1))];

shock=[0;0;sigma_mu];

[XX,YY,ZZ]=impulse_response(NN,PP,QQ,RR,SS,shock,H,N);

cc = zeros(H+2,N);
zz = zeros(H+2,N-1);

for i=1:N,
   cc(:,i)=YY(i+1,:)';
end
for i=1:N-1,
   zz(:,i)=XX(i,:)';
end

mu=ZZ(3,:)';
pi=YY(1,:)';

T=length(mu);
t=cumsum(ones(T,1));

log_M=cumsum(mu);
log_P=cumsum(pi);
log_V=log_P-log_M;

xmin=-1;
xmax=60;
ymin=-0.5;
ymax=1.5;

figure(1)
plot(hs,log_M,hs,log_V,hs,log_P,hs,zeros(H+2,1),'k--')
title('Money up, velocity down, prices sluggish')
xlabel('months after shock')
ylabel('response to unit shock')
legend('log(M)','log(v)','log(P)',2)
axis([-1 10 -0.5 1.5])




time=toc;

   